@@ -903,7 +903,9 @@ int kr_resolve_consume(struct kr_request *request, struct kr_transport **transpo
 
 	/* Do not finish with bogus answer. */
 	if (qry->flags.DNSSEC_BOGUS)  {
-		if (qry->flags.FORWARD || qry->flags.STUB) {
+		if (qry->flags.FORWARD || qry->flags.STUB
+				/* Probably CPU exhaustion attempt, so do not retry. */
+				|| qry->vld_limit_crypto_remains <= 0) {
 			return KR_STATE_FAIL;
 		}
 		/* Other servers might not have broken DNSSEC. */
@@ -1707,7 +1709,7 @@ int kr_request_set_extended_error(struct kr_request *request, int info_code, con
 		return KNOT_EDNS_EDE_NONE;
 	}
 
-	if (ede_priority(info_code) >= ede_priority(ede->info_code)) {
+	if (ede_priority(info_code) > ede_priority(ede->info_code)) {
 		ede->info_code = info_code;
 		ede->extra_text = extra_text;
 	}
