@@ -503,7 +503,7 @@ static inline uint16_t kr_rrset_type_maysig(const knot_rrset_t *rr)
  * \note it may be outdated in case of long callbacks; see uv_now().
  */
 KR_EXPORT
-uint64_t kr_now();
+uint64_t kr_now(void);
 
 /** Call free(handle->data); it's useful e.g. as a callback in uv_close(). */
 KR_EXPORT void kr_uv_free_cb(uv_handle_t* handle);
@@ -606,3 +606,14 @@ KR_EXPORT long long kr_fssize(const char *path);
 /** Simply return de->dname. (useful from Lua) */
 KR_EXPORT const char * kr_dirent_name(const struct dirent *de);
 
+
+/* trivial libknot versions compatibility */
+static inline size_t kr_dname_prefixlen(const uint8_t *name, unsigned nlabels)
+{
+	return knot_dname_prefixlen(name, nlabels
+		#if KNOT_VERSION_HEX < 0x030400
+			, NULL
+		#endif
+	);
+}
+
